///////////////////////////////////////////////////////////////////////////////
// AW7HUD
// Heat vision stuff as well as other AW7-specific overlays
///////////////////////////////////////////////////////////////////////////////
class AW7EDHUD extends AWWrapHUD;

const TIME_X = 0.95;
const TIME_Y = 0.95;

///////////////////////////////////////////////////////////////////////////////
// Cross for drawing police radio beacons
///////////////////////////////////////////////////////////////////////////////
var() Texture TheCross;

///////////////////////////////////////////////////////////////////////////////
// Draw weapon section
///////////////////////////////////////////////////////////////////////////////
simulated function DrawWeapon(canvas Canvas, float Scale)
	{
	local Texture usetex;
	local Texture usetex2;
	local P2Weapon myweap;
	local String str1, str2;

	//log(self$" draw weapon, "$PawnOwner.Weapon);
	//if(PawnOwner.Weapon != None)
	//	log(self$" ammo "$P2AmmoInv(PawnOwner.Weapon.AmmoType));
	if(PawnOwner.Weapon != None && P2AmmoInv(PawnOwner.Weapon.AmmoType) != None)
		{
		// Draw background
		Canvas.Style = ERenderStyle.STY_Masked;
		Canvas.DrawColor = DefaultIconColor;
		Canvas.SetPos(
			(IconPos[WeapIndex].X + HUD_BACKGROUND_X_OFFSET)*CanvasWidth,
			(IconPos[WeapIndex].Y + HUD_BACKGROUND_Y_OFFSET)*CanvasHeight);
		Canvas.DrawIcon(Texture(SectionBackground[HUD_AMMO]), Scale);
		
		// Draw ammo icon
		Canvas.Style = ERenderStyle.STY_Masked;
		Canvas.DrawColor = DefaultIconColor;
		usetex = Texture(PawnOwner.Weapon.AmmoType.Texture);
		usetex2 = Texture(PawnOwner.Weapon.Texture);
		if(usetex != None)
			{
			Canvas.SetPos(
				IconPos[WeapIndex].X*CanvasWidth - Scale*(usetex.USize/2),
				IconPos[WeapIndex].Y*CanvasHeight - Scale*(usetex.VSize/2));
			Canvas.DrawIcon(usetex, Scale);
			}

		if(usetex == None && usetex2 !=None)
			{
			Canvas.SetPos(
				IconPos[WeapIndex].X*CanvasWidth - Scale*(usetex.USize/2),
				IconPos[WeapIndex].Y*CanvasHeight - Scale*(usetex.VSize/2));
			Canvas.DrawIcon(usetex2, Scale);
			}

		// Draw ammo count in text number form
		if(P2AmmoInv(PawnOwner.Weapon.AmmoType).bShowAmmoOnHud)
			{
			MyFont.DrawTextEx(Canvas, CanvasWidth, 
				(IconPos[WeapIndex].X+HUD_NUMBERS_OFFSET_X)*CanvasWidth,
				(IconPos[WeapIndex].Y+HUD_NUMBERS_OFFSET_Y)*CanvasHeight,
				""$PawnOwner.Weapon.AmmoType.AmmoAmount, 2);

			if(P2AmmoInv(PawnOwner.Weapon.AmmoType).bShowMaxAmmoOnHud)
				{
				MyFont.DrawTextEx(Canvas, CanvasWidth, 
					(IconPos[WeapIndex].X+HUD_NUMBERS_MAX_AMMO_OFFSET_X)*CanvasWidth,
					(IconPos[WeapIndex].Y+HUD_NUMBERS_OFFSET_Y)*CanvasHeight,
					"/"$PawnOwner.Weapon.AmmoType.MaxAmmo, 2);
				}
			}

		// Draw text hints
		myweap = P2Weapon(PawnOwner.Weapon);
		if(myweap != None
			&& P2GameInfoSingle(Level.Game) != None
			&& P2GameInfo(Level.Game).AllowInventoryHints())
			{
			// Weapon hints (how to use them)
			if(WeapHintDeathTime > Level.TimeSeconds
				|| WeapHintDeathTime == INFINITE_HINT_TIME)
				{
				if (WeapHint1 != "")
					MyFont.DrawTextEx(Canvas, CanvasWidth, (IconPos[WeapIndex].X+WeapTextPos[0].X) * CanvasWidth, 
											(IconPos[WeapIndex].Y+WeapTextPos[0].Y) * CanvasHeight, WeapHint1, 0, true, EJ_Right);
				if (WeapHint2 != "")
					MyFont.DrawTextEx(Canvas, CanvasWidth, (IconPos[WeapIndex].X+WeapTextPos[1].X) * CanvasWidth, 
											(IconPos[WeapIndex].Y+WeapTextPos[1].Y) * CanvasHeight, WeapHint2, 0, true, EJ_Right);
				if (WeapHint3 != "")
					MyFont.DrawTextEx(Canvas, CanvasWidth, (IconPos[WeapIndex].X+WeapTextPos[2].X) * CanvasWidth, 
											(IconPos[WeapIndex].Y+WeapTextPos[2].Y) * CanvasHeight, WeapHint3, 0, true, EJ_Right);
				}
			}
		}
	}
///////////////////////////////////////////////////////////////////////////////
// PostRender
// Render heat vision in addition to normal HUD overlays.
///////////////////////////////////////////////////////////////////////////////
simulated event PostRender(canvas Canvas)
{
	local HUD H;
	local float YL,YPos;
	local Pawn P;

	// If a movie is playing, let Super handle everything
	if(TextureMovie != NONE && TextureMovie.Movie != NONE && TextureMovie.Movie.IsPlaying())
	{
		Super.PostRender(Canvas);
		return;
	}

	// If there's an active screen, check to see if it wants the hud
	// If there's a root window running then never show the hud
	if ((OurPlayer.CurrentScreen == None || OurPlayer.CurrentScreen.ShouldDrawHUD()) && !AreAnyRootWindowsRunning())
	{
		if ( !OurPlayer.bBehindView )
		{
			// Draw your foot in now
			if ( (PawnOwner != None) && (PawnOwner.MyFoot != None) )
				PawnOwner.MyFoot.RenderOverlays(Canvas);
		}

		// Do rest of weapons and hud
		if ( !OurPlayer.bBehindView )
		{
			P = Pawn(OurPlayer.ViewTarget);
			if ( (P != None) && (P.Weapon != None) )
				P.Weapon.RenderOverlays(Canvas);
		}

		// Of course, cast OurPlayer to your BulletPlayer class instead of ED_HeatVisionPlayer
		if (AW7DudePlayer(OurPlayer) != None && AW7DudePlayer(OurPlayer).bHeatVisionActive)
			AW7DudePlayer(OurPlayer).RenderHeatvisionOverlay(Canvas);

		DisplayMessages(Canvas);

		DrawTimeOnScreen(Canvas);

		bHideCenterMessages = DrawLevelAction(Canvas);

		if ( !bHideCenterMessages && (OurPlayer.ProgressTimeOut > Level.TimeSeconds) )
			DisplayProgressMessage(Canvas);

		if ( bBadConnectionAlert )
			DisplayBadConnectionAlert();

		if ( bShowDebugInfo )
		{
			YPos = 5;
			UseSmallFont(Canvas);
			OurPlayer.ViewTarget.DisplayDebug(Canvas,YL,YPos);
		}
		else for ( H=self; H!=None; H=H.NextHUD )
			H.DrawHUD(Canvas);

	// Give game info a chance to show debug stuff
	if (P2GameInfoSingle(Level.Game) != None)
		P2GameInfoSingle(Level.Game).RenderOverlays(Canvas);
	}

	// Display text saying who this version was issued to
	DrawIssuedToText(Canvas);

	if (OurPlayer.Pawn != None && OurPlayer.Pawn.FindInventoryType(class'CopRadioInv') != None)
		DrawRadioBeacons(Canvas);

//	DrawCellBeacons(Canvas);
}

///////////////////////////////////////////////////////////////////////////////
// Draws a cop beacon on the radar.
///////////////////////////////////////////////////////////////////////////////
function DrawBeaconOnRadar (CopRadioBeacon Target, Canvas Canvas)
{
	local vector MyLocation;
	local vector TargetLocation;
	local vector DiffLocation;
	local vector X,Y,Z;

	local float  ScreenPosX;
	local float  ScreenPosY;

	local string DistanceInfo;
	local string HealthInfo;
	local string NameInfo;
	local color OurDrawColor;
	//local string WpnInfo, InvInfo;

	if (OurPlayer.ViewTarget != None)
	{
		MyLocation = OurPlayer.ViewTarget.Location;
		if (Pawn(OurPlayer.Viewtarget) != None)
			MyLocation.Z += Pawn(OurPlayer.Viewtarget).EyeHeight;
	}
	else
		MyLocation = OurPlayer.Location;

	TargetLocation = Target.Location;
	TargetLocation.Z += Target.CollisionHeight / 2;

	DiffLocation = TargetLocation - MyLocation;

	GetAxes(Normalize(OurPlayer.Rotation),X,Y,Z);

	if (DiffLocation Dot X > 0.70)
	{
		//log("Attempting to draw" @ Target @ "on" @ Canvas);
		ScreenPosX = (Canvas.ClipX / 2) + ( (DiffLocation Dot Y)) * ((Canvas.ClipX / 2) / Tan(OurPlayer.FovAngle * Pi/360)) / (DiffLocation Dot X);
		ScreenPosY = (Canvas.ClipY / 2) + (-(DiffLocation Dot Z)) * ((Canvas.ClipX / 2) / Tan(OurPlayer.FovAngle * Pi/360)) / (DiffLocation Dot X);

		Canvas.SetPos(ScreenPosX - 8, ScreenPosY - 8);
		OurDrawColor=RedColor;

		if (Target.TimerRate - Target.TimerCounter <= 10)
		{
			OurDrawColor.A = Int(255*(Target.TimerRate - Target.TimerCounter)/10);
			//log("it's"@OurDrawColor.A);
		}
		Canvas.DrawColor = OurDrawColor;
		Canvas.Style=ERenderStyle.STY_Alpha;
		Canvas.DrawIcon(TheCross, 0.5);

		DistanceInfo = String(Int(VSize(DiffLocation) / 48));

		Canvas.Font = Canvas.SmallFont;

		Canvas.SetPos(ScreenPosX + 10, ScreenPosY);
		Canvas.DrawText(DistanceInfo);
	}
}

///////////////////////////////////////////////////////////////////////////////
// Draw all cop radio beacons
///////////////////////////////////////////////////////////////////////////////
function DrawRadioBeacons(canvas Canvas)
{
	local CopRadioBeacon B;

	foreach DynamicActors(class'CopRadioBeacon', B)
		DrawBeaconOnRadar(B, Canvas);
}

/*
function DrawCellBeacons(canvas Canvas)
{
	local CellBeacon B;

	foreach DynamicActors(class'CellBeacon', B)
		DrawBeaconOnRadar(B, Canvas);
}
*/

function string LZero(int N, int Places)
{
	local string S;
	local int i;

	S = String(N);
	for (i=0; len(S)<Places; i++)
		S = "0" $ S;

	return S;
}

simulated function DrawTimeOnScreen(Canvas C)
{
	local float Elapsed;
	local int Hours;
	local int Minutes;
	local float HrMin;
	local int Seconds;
	local string FinalOut;
	local float Excess;
	local int Centi;

	if (AW7GameState(P2GameInfoSingle(Level.Game).TheGameState) == None
		|| !AW7GameInfo(Level.Game).bDrawTime)
		return;

	Elapsed = AW7GameState(P2GameInfoSingle(Level.Game).TheGameState).TimeElapsed;

	Hours = int(Elapsed/3600);

	Minutes = Int((Elapsed - float(Hours*3600)) / 60);

	Seconds = Int((Elapsed - float(Hours*3600) - float(Minutes*60)));

	Excess = Hours*3600 + Minutes*60 + Seconds;
	Centi = int((Elapsed - Excess) * 100);

//	Minutes = int(Elapsed/60);

//	HrMin = Hours*3600 + Minutes*60;

//	Seconds = int(Elapsed - HrMin);
//	Excess = Elapsed - HrMin - Seconds;
//	Centi = int(Excess * 100);

	FinalOut = LZero(Hours,2) $ ":" $ LZero(Minutes, 2) $ ":" $ LZero(Seconds, 2) $ "." $ LZero(Centi, 2);

	MyFont.TextColor = WhiteColor;
	MyFont.DrawTextEX(C, CanvasWidth, TIME_X * CanvasWidth, TIME_Y * CanvasHeight, FinalOut, 1, true, EJ_Right);
	MyFont.TextColor = RedColor;
}

///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     TheCross=Texture'AW7Tex.Misc.MyCross'
     startinjuries(0)=(Tex=Texture'Zo_Smeg.Special_Brushes.zo_gravel',xoff=-0.500000,yoff=-0.500000,Scale=2.000000,MoveTimeDilation=1.000000,MoveSpeed=0.400000,Red=255.000000,Green=100.000000,Blue=128.000000,Alpha=80.000000,redchange=2.000000,greenchange=-2.000000,bluechange=5.000000,alphachange=-18.000000,redmax=255.000000,greenmax=100.000000,bluemax=128.000000,AlphaMax=128.000000,redmin=200.000000,greenmin=60.000000,bluemin=50.000000,alphamin=1.000000)
     startinjuries(1)=(Tex=Texture'Zo_Smeg.Special_Brushes.zo_wash2_opaque',xoff=-0.500000,yoff=-0.500000,Scale=2.000000,MoveTimeDilation=1.500000,MoveSpeed=-0.200000,Red=40.000000,Green=20.000000,Blue=200.000000,Alpha=80.000000,greenchange=3.000000,bluechange=-4.000000,alphachange=-18.000000,redmax=100.000000,greenmax=120.000000,bluemax=255.000000,AlphaMax=128.000000,redmin=100.000000,greenmin=40.000000,bluemin=200.000000,alphamin=1.000000)
     startinjuries(2)=(Tex=Texture'Zo_Smeg.Ground_Alphas.zo_grnd_alpha2',Scale=1.000000,MoveTimeDilation=1.000000,Red=255.000000,Green=255.000000,Blue=255.000000,Alpha=255.000000,alphachange=-80.000000,AlphaMax=255.000000,alphamin=1.000000)
     walkinjuries(0)=(Tex=Texture'Zo_Smeg.Special_Brushes.zo_gravel',xoff=-0.500000,yoff=-0.500000,Scale=2.000000,MoveTimeDilation=0.500000,MoveSpeed=0.200000,Red=255.000000,Alpha=1.000000,redchange=2.000000,bluechange=1.000000,alphachange=4.000000,redmax=255.000000,bluemax=80.000000,AlphaMax=50.000000,redmin=200.000000,bluemin=1.000000,alphamin=20.000000)
     walkinjuries(1)=(Tex=Texture'Zo_Smeg.Special_Brushes.zo_wash2_opaque',xoff=-0.500000,yoff=-0.500000,Scale=2.000000,MoveTimeDilation=0.800000,MoveSpeed=-0.100000,Red=100.000000,Green=100.000000,Blue=200.000000,Alpha=1.000000,greenchange=1.000000,bluechange=-4.000000,alphachange=7.000000,redmax=100.000000,greenmax=255.000000,bluemax=255.000000,AlphaMax=50.000000,redmin=100.000000,greenmin=20.000000,bluemin=200.000000,alphamin=20.000000)
     stopinjuries(0)=(Tex=Texture'Zo_Smeg.Ground_Alphas.zo_grnd_alpha2',Scale=1.000000,MoveTimeDilation=1.000000,Red=255.000000,Green=255.000000,Blue=255.000000,Alpha=255.000000,alphachange=-80.000000,AlphaMax=255.000000,alphamin=1.000000)
     stopinjuries(1)=(Tex=Texture'Zo_Smeg.Ground_Alphas.zo_grnd_alpha2',Scale=1.000000,MoveTimeDilation=1.000000,Red=255.000000,Green=255.000000,Blue=255.000000,Alpha=255.000000,alphachange=-80.000000,AlphaMax=255.000000,alphamin=1.000000)
     garyeffects(0)=(Tex=Texture'Zo_Smeg.Special_Brushes.zo_gravel',xoff=-0.500000,yoff=-0.500000,Scale=2.000000,MoveTimeDilation=0.600000,MoveSpeed=0.300000,Green=180.000000,Alpha=1.000000,greenchange=2.000000,bluechange=1.000000,alphachange=3.000000,greenmax=180.000000,bluemax=80.000000,AlphaMax=50.000000,greenmin=100.000000,bluemin=1.000000,alphamin=20.000000)
     garyeffects(1)=(Tex=Texture'Zo_Smeg.Special_Brushes.zo_wash2_opaque',xoff=-0.500000,yoff=-0.500000,Scale=2.000000,MoveTimeDilation=0.700000,MoveSpeed=-0.150000,Red=50.000000,Green=100.000000,Blue=200.000000,Alpha=1.000000,greenchange=1.000000,bluechange=-4.000000,alphachange=7.000000,redmax=100.000000,greenmax=100.000000,bluemax=255.000000,AlphaMax=50.000000,redmin=50.000000,greenmin=20.000000,bluemin=200.000000,alphamin=20.000000)
     SectionBackground(0)=Texture'nathans.Inventory.bloodsplat-1'
     SectionBackground(1)=Texture'nathans.Inventory.bloodsplat-2'
     SectionBackground(2)=Texture'nathans.Inventory.bloodsplat-3'
     IconPos(0)=(X=0.935000,Y=0.120000)
     IconPos(1)=(X=0.935000,Y=0.270000)
     IconPos(2)=(X=0.935000,Y=0.420000)
     IconPos(3)=(X=0.935000,Y=0.570000)
     InvTextPos(0)=(X=-0.055000,Y=-0.035000)
     InvTextPos(1)=(X=-0.055000,Y=-0.010000)
     InvTextPos(2)=(X=-0.055000,Y=0.015000)
     WeapTextPos(0)=(X=-0.055000,Y=0.015000)
     WeapTextPos(1)=(X=-0.055000,Y=0.040000)
     WeapTextPos(2)=(X=-0.055000,Y=0.065000)
     WantedTextPos(0)=(X=-0.055000,Y=-0.030000)
     WantedTextPos(1)=(X=-0.055000)
}
