class AW7EDMenuGameSettings extends MenuGameSettings;

///////////////////////////////////////////////////////////////////////////////
// Vars, structs, consts, enums...
///////////////////////////////////////////////////////////////////////////////

var() class<ShellMenuCW> MenuReticleClass;

const c_strCartoonyPath = "AW7FX.AW7EarlyGameInfo bCartoonyEffects";
var UWindowCheckbox CartoonyCheckbox;
var localized string CartoonyText;
var localized string CartoonyHelp;

const c_strShinyPath = "AW7FX.AW7EarlyGameInfo bShinyWeapons";
var UWindowCheckbox ShinyCheckbox;
var localized string ShinyText;
var localized string ShinyHelp;

const c_strNewOrderPath = "AW7EDGame.AW7EDGameInfo bNewWeaponOrder";
var UWindowCheckbox NewOrderCheckbox;
var localized string NewOrderText;
var localized string NewOrderHelp;

const c_strDrawPath = "AW7EDGame.AW7EDGameInfo bDrawTime";
var UWindowCheckbox DrawTimeCheckbox;
var localized string DrawTimeText;
var localized string DrawTimeHelp;

///////////////////////////////////////////////////////////////////////////////
// Create menu contents
///////////////////////////////////////////////////////////////////////////////
function CreateMenuContents()
{
	Super(ShellMenuCW).CreateMenuContents();
	AddTitle(GameSettingsTitleText, TitleFont, TitleAlign);

	ReticleChoice			= AddChoice(ReticleText, ReticleHelp, ItemFont, ItemAlign);
	AutoSaveCheckbox		= AddCheckbox(AutoSaveText, AutoSaveHelp, ItemFont);
	GoreCheckbox			= AddCheckbox(GoreText, GoreHelp, ItemFont);
	InvHintsCheckbox		= AddCheckbox(InvHintsText, InvHintsHelp, ItemFont);
	GameHintsCheckbox		= AddCheckbox(GameHintsText, GameHintsHelp, ItemFont);
	MpHintsCheckbox   = AddCheckbox(MpHintsText, MpHintsHelp, ItemFont);
	WeaponSwitchCheckbox    = AddCheckbox(WeaponSwitchText, WeaponSwitchHelp, ItemFont);
	WeaponEmptyCheckbox     = AddCheckbox(WeaponEmptyText, WeaponEmptyHelp, ItemFont);
	DamageFlashSlider		= AddSlider(DamageFlashText, DamageFlashHelp, ItemFont, 0, 255);
	WeaponBobCheckbox		= AddCheckbox(WeaponBobText, WeaponBobHelp, ItemFont);
	TracersCheckbox			= AddCheckbox(TracersText, TracersHelp, ItemFont);
	ShinyCheckbox			= AddCheckbox(ShinyText, ShinyHelp, ItemFont);
	//CartoonyCheckbox		= AddCheckbox(CartoonyText, CartoonyHelp, ItemFont);
	DrawTimeCheckbox		= AddCheckbox(DrawTimeText, DrawTimeHelp, ItemFont);
	NewOrderCheckbox		= AddCheckbox(NewOrderText, NewOrderHelp, ItemFont);

	RestoreChoice    = AddChoice(RestoreText, RestoreHelp,	ItemFont, ItemAlign);
	BackChoice       = AddChoice(BackText,    "",			ItemFont, ItemAlign, true);

	LoadValues();
}

///////////////////////////////////////////////////////////////////////////////
// Load all values from ini files
///////////////////////////////////////////////////////////////////////////////
function LoadValues()
{
	local float val;
	local bool flag;
	local String detail;
	local int i;

	Super.LoadValues();

	// Controls will generate Notify() events when their values are updated, so we
	// use this flag to block the events from actually doing anything.  In other
	// words, we're only setting the initial values of the controls and we don't
	// want that to count as a change.
	bUpdate = False;

	// Value 0 or 1
//	flag = bool(GetPlayerOwner().ConsoleCommand("get"@c_strCartoonyPath));
//	CartoonyCheckbox.SetValue(flag);
	flag = bool(GetPlayerOwner().ConsoleCommand("get"@c_strDrawPath));
	DrawTimeCheckbox.SetValue(flag);

	// Value 0 or 1
	flag = bool(GetPlayerOwner().ConsoleCommand("get"@c_strNewOrderPath));
	NewOrderCheckbox.SetValue(flag);

	// Value 0 or 1
	flag = bool(GetPlayerOwner().ConsoleCommand("get"@c_strShinyPath));
	ShinyCheckbox.SetValue(flag);

	bUpdate = True;
}

function ShinyCheckboxChanged()
	{
	if (bUpdate)
		{
		GetPlayerOwner().ConsoleCommand("set"@c_strShinyPath@ShinyCheckbox.bChecked);
		if (ShinyCheckbox.bChecked)
			AW7GameInfo(GetPlayerOwner().Level.Game).HackMakeShiny();
		else
			AW7GameInfo(GetPlayerOwner().Level.Game).HackMakeUnShiny();
		}
	}

function CartoonyCheckboxChanged()
	{
	if (bUpdate)
		{
		GetPlayerOwner().ConsoleCommand("set"@c_strCartoonyPath@CartoonyCheckbox.bChecked);
		}
	}

function DrawTimeChanged()
	{
	if (bUpdate)
		{
		GetPlayerOwner().ConsoleCommand("set"@c_strDrawPath@DrawTimeCheckbox.bChecked);
		}
	}

function NewOrderCheckboxChanged()
	{
	if (bUpdate)
		{
		GetPlayerOwner().ConsoleCommand("set"@c_strNewOrderPath@NewOrderCheckbox.bChecked);
		AW7GameInfo(GetPlayerOwner().Level.Game).SetWeaponOrder();
		}
	}

///////////////////////////////////////////////////////////////////////////////
// Callback for when control has changed
///////////////////////////////////////////////////////////////////////////////
function Notify(UWindowDialogControl C, byte E)
{
	if (E == DE_Click && C == ReticleChoice)
		Super(ShellMenuCW).Notify(C, E);
	else
		Super.Notify(C, E);

	switch (E)
		{
		case DE_Change:
			switch (C)
				{
				case CartoonyCheckbox:
					CartoonyCheckboxChanged();
					break;
				case DrawTimeCheckbox:
					DrawTimeChanged();
					break;
				case NewOrderCheckbox:
					NewOrderCheckboxChanged();
					break;
				case ShinyCheckbox:
					ShinyCheckboxChanged();
					break;
				}
			break;
		case DE_Click:
			switch (C)
				{
				case ReticleChoice:
					GoToMenu(MenuReticleClass);
					break;
				}
			break;
		}
}

///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     MenuReticleClass=Class'AW7EDShell.AW7EDMenuReticle'
     CartoonyText="Cartoony Effects"
     CartoonyHelp="Enables 'cartoony' effects for certain weapons (M@D Bomb, M@D Warhammer)"
     ShinyText="Shiny Weapons"
     ShinyHelp="Makes various weapons (machete, axe, etc.) extra-shiny"
     NewOrderText="New Weapon Order"
     NewOrderHelp="Moves 'cutting' weapons to Group 2 and pistols to Group 3 (reduces clutter in Group 1)"
     DrawTimeText="Show Game Timer"
     DrawTimeHelp="Displays game timer (for time attack)"
     astrTextureDetailNames(0)="UltraLow"
     astrTextureDetailNames(1)="Low"
     astrTextureDetailNames(2)="Medium"
     astrTextureDetailNames(3)="High"
}
