class AW7EDMenuPerformanceAdvanced extends MenuPerformanceAdvanced;

///////////////////////////////////////////////////////////////////////////////
// Vars, structs, consts, enums...
///////////////////////////////////////////////////////////////////////////////
const c_strHeadFixPath = "AW7FXShell.AW7EarlyGameInfo bHeadFix";
var UWindowCheckbox HeadFixCheckbox;
var localized string HeadFixText;
var localized string HeadFixHelp;

const c_strLimbFixPath = "AW7FX.AW7EarlyGameInfo bLimbFix";
var UWindowCheckbox LimbFixCheckbox;
var localized string LimbFixText;
var localized string LimbFixHelp;

///////////////////////////////////////////////////////////////////////////////
// Create menu contents
///////////////////////////////////////////////////////////////////////////////
function CreateMenuContents()
	{
	Super(ShellMenuCW).CreateMenuContents();

	TitleAlign = TA_Center;
	AddTitle(PerformanceTitleText, TitleFont, TitleAlign);

	// 12/17/02 NPF Use a smaller font than was set by the base class.
	ItemFont	= F_FancyM;

	GenEndSlider   = AddSlider(GenEndText,   GenEndHelp,   ItemFont, 0, 1);
	GenEndSlider  .SetRange(c_fMinFogMeters, c_fMaxFogMeters, c_fFogStepMeters);	// Have to reset range to set step.  Can reach in to Step field but this function makes sure the value is set to a step.
	InfiniteViewCheckbox = AddCheckbox(InfiniteViewText, InfiniteViewHelp, ItemFont);	// 01/19/03 JMI Added to disable fog.
	TextureDetailWorldSlider = AddSlider(TextureDetailWorldText, TextureDetailWorldHelp, ItemFont, 1, 3);	// Don't allow lower than 1 or engine will crash
	TextureDetailWorldSlider.SetVals(astrDetailVals4);
	TextureDetailSkinSlider = AddSlider(TextureDetailSkinText, TextureDetailSkinHelp, ItemFont, 1, 3);	// Don't allow lower than 1 or engine will crash
	TextureDetailSkinSlider.SetVals(astrDetailVals4);
	TextureDetailLightmapSlider = AddSlider(TextureDetailLightmapText, TextureDetailLightmapHelp, ItemFont, 1, 3);	// Don't allow lower than 1 or engine will crash
	TextureDetailLightmapSlider.SetVals(astrDetailVals4);
	//GameDetailCheckbox = AddCheckbox(GameDetailText, GameDetailHelp, ItemFont);
	//WorldDetailSlider = AddSlider(WorldDetailSliderText, WorldDetailSliderHelp, ItemFont, 0, 1);
	//ShadowSlider = AddSlider(ShadowText, ShadowHelp, ItemFont, 0, 2);
	//ShadowSlider.SetVals(astrDetailVals3);
	//DynamicLightsCheckbox = AddCheckbox(DynamicLightsText, DynamicLightsHelp, ItemFont);
	FireSlider = AddSlider(FireText, FireHelp, ItemFont, 0, 10);
	SmokeSlider = AddSlider(SmokeText, SmokeHelp, ItemFont, 0, 10);
	BloodSpoutCheckbox = AddCheckbox(BloodSpoutText, BloodSpoutHelp, ItemFont);
	DecalSlider = AddSlider(DecalText, DecalHelp, ItemFont, 0, 10);
	ProjectorsCheckbox = AddCheckbox(ProjectorsText, ProjectorsHelp, ItemFont);
	PawnSlider = AddSlider(PawnText, PawnHelp, ItemFont, 0, 50);
	BodiesSlider = AddSlider(BodiesSliderText, BodiesSliderHelp, ItemFont, 0, 200);
	RagdollSlider = AddSlider(RagdollText, RagdollHelp, ItemFont, 0, 10);
	// 02/16/03 JMI Moved to bottom--this is where the other quantitative values are and this is one
	//				we prefer they don't turn off so it's last.
	WorldDetailObjsCheckbox = AddCheckbox(WorldDetailObjsText, WorldDetailObjsHelp, ItemFont);
	LimbFixCheckbox = AddCheckbox(LimbFixText, LimbFixHelp, ItemFont);
	HeadFixCheckbox = AddCheckbox(HeadFixText, HeadFixHelp, ItemFont);

	RestoreChoice	= AddChoice(RestoreText,	RestoreHelp,	ItemFont, ItemAlign);
	BackChoice		= AddChoice(BackText,		"",				ItemFont, ItemAlign, true);

	LoadValues();
	}

///////////////////////////////////////////////////////////////////////////////
// Load all values from ini files
///////////////////////////////////////////////////////////////////////////////
function LoadValues()
{
	local float val;
	local bool flag;
	local String detail;
	local int i;

	Super.LoadValues();

	// Controls will generate Notify() events when their values are updated, so we
	// use this flag to block the events from actually doing anything.  In other
	// words, we're only setting the initial values of the controls and we don't
	// want that to count as a change.
	bUpdate = False;

	// Value 0 or 1
	flag = bool(GetPlayerOwner().ConsoleCommand("get"@c_strHeadFixPath));
	HeadFixCheckbox.SetValue(flag);

	// Value 0 or 1
	flag = bool(GetPlayerOwner().ConsoleCommand("get"@c_strLimbFixPath));
	LimbFixCheckbox.SetValue(flag);

	bUpdate = True;
}

function HeadFixCheckboxChanged()
	{
	if (bUpdate)
		{
		GetPlayerOwner().ConsoleCommand("set"@c_strHeadFixPath@HeadFixCheckbox.bChecked);
		}
	}

function LimbFixCheckboxChanged()
	{
	if (bUpdate)
		{
		GetPlayerOwner().ConsoleCommand("set"@c_strLimbFixPath@LimbFixCheckbox.bChecked);
		}
	}

///////////////////////////////////////////////////////////////////////////////
// Handle notifications from controls
///////////////////////////////////////////////////////////////////////////////
function Notify(UWindowDialogControl C, byte E)
{
	Super.Notify(C, E);

	switch (E)
	{
		case DE_Change:
			switch (C)
				{
				case HeadFixCheckbox:
					HeadFixCheckboxChanged();
					break;
				case LimbFixCheckbox:
					LimbFixCheckboxChanged();
					break;
				}
			break;
	}
}

///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     HeadFixText="Head Fix"
     HeadFixHelp="Attempt to reduce crashes by removing severed heads"
     LimbFixText="Limb Fix"
     LimbFixHelp="Attempt to reduce crashes by removing severed limbs"
     astrDetailVals3(0)="off"
     astrDetailVals3(1)="low"
     astrDetailVals3(2)="high"
     astrDetailVals4(0)="very low"
     astrDetailVals4(1)="low"
     astrDetailVals4(2)="medium"
     astrDetailVals4(3)="high"
     astrTextureDetailNames(0)="UltraLow"
     astrTextureDetailNames(1)="Low"
     astrTextureDetailNames(2)="Medium"
     astrTextureDetailNames(3)="High"
}
